import org.modeshape.jcr.JcrConfiguration;
import org.modeshape.jcr.JcrEngine;
import org.modeshape.jcr.JcrRepository;
import org.xml.sax.SAXException;
import javax.jcr.Binary;
import javax.jcr.Node;
import javax.jcr.NodeIterator;
import javax.jcr.Property;
import javax.jcr.PropertyIterator;
import javax.jcr.RepositoryException;
import javax.jcr.Session;
import javax.jcr.Value;
import javax.jcr.nodetype.NodeType;
import javax.jcr.nodetype.NodeTypeIterator;
import javax.jcr.query.Query;
import javax.jcr.query.QueryManager;
import javax.jcr.query.QueryResult;
import javax.jcr.query.Row;
import javax.jcr.query.RowIterator;
import org.modeshape.sequencer.text.DelimitedTextSequencer;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.Iterator;
 
 
public class TestJCR {
 
    public static void main(String[] args) throws IOException, SAXException, RepositoryException {
        TestJCR j = new TestJCR();
        j.doExample();
    }
 
    public void doExample() throws IOException, SAXException, RepositoryException {
        final String JCR_CONFIG_FILE_URL = "modeshape_beginners_config.xml";
        final String REPO_NAME = "beginners_repo";
        final String WORKSPACE_NAME = "beginners_workspace";
 
        // Assuming config file is at root of project's classpath
        final File configFile = new File(this.getClass().getResource(JCR_CONFIG_FILE_URL).getPath());
 
        // Configure the JCR engine
        final JcrConfiguration jcrConfig = new JcrConfiguration();       // org.modeshape.jcr.JcrConfiguration
        final JcrEngine engine = jcrConfig.loadFrom(configFile).build(); // org.modeshape.jcr.JcrEngine;
        engine.start();
 
        final JcrRepository repo = engine.getRepository(REPO_NAME);      // org.modeshape.jcr.JcrRepository
        final Session session = repo.login(WORKSPACE_NAME);              // javax.jcr.Session
 
        File file = new File("people.csv");
        
        if(file.exists())
        	System.out.println("File exists");
        
        final FileInputStream inputStream = new FileInputStream(file);
        final Binary binaryFileData = session.getValueFactory().createBinary(inputStream);
        
        final Node rootNode = session.getRootNode();
        final Node testFolder = rootNode.addNode("test_folder", "nt:folder");
        final Node fileNode = testFolder.addNode("people.csv", "nt:file");
        
        final Node fileContent = fileNode.addNode("jcr:content", "nt:resource");
        fileContent.setProperty("jcr:data", binaryFileData);
        session.save();

        try {
			Thread.sleep(500);
		} catch (InterruptedException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

        if(session.getNode("/test_folder/people.csv") != null){
        	System.out.println("Successful Sequencing");
        }
        
        final String jql = "SELECT * from [text:column]";
        
        final QueryManager queryManager = session.getWorkspace().getQueryManager();  // javax.jcr.QueryManager
        final Query query = queryManager.createQuery(jql, Query.JCR_SQL2);           // javax.jcr.Query
        final QueryResult queryResult = query.execute();                             // javax.jcr.QueryResult

        System.out.println(queryResult);
                
        // Clean shutdown
        session.logout();
        engine.shutdown();
    }
 
}